CREATE OR REPLACE FUNCTION schedule_email(
    v_recipients        text[],
    v_subject           text,
    v_msgbody           text,
    v_cc_recipients     text[] DEFAULT ARRAY[]::text[],
    v_bcc_recipients    text[] DEFAULT ARRAY[]::text[],
    v_content_type      text DEFAULT 'text/plain; charset=UTF-8'::text
)
RETURNS void AS
$$
    DECLARE
        v_chain_id          bigint;
        v_mail_task_id      bigint;
        v_base_parameters   jsonb;
    BEGIN
    /*
      smtp credentials and commomn parameters could be stored in cypex.t_config.
      {
        "password": "strong_password",
        "username": "smtp_user",
        "senderaddr": "do_not_answer@server.com",
        "serverhost": "mail.server.com",
        "serverport": 110
    }
    */

    SELECT value::jsonb INTO v_base_parameters FROM cypex.t_config WHERE key = 'smtp_config';

    IF v_base_parameters IS NULL THEN
        RAISE EXCEPTION 'smtp_config missing';
    END IF;

    -- Get the chain id
    INSERT INTO timetable.chain (chain_name, max_instances, live) VALUES ('Send Mail', 1, TRUE)
    RETURNING chain_id INTO v_chain_id;

    -- Add SendMail task
    INSERT INTO timetable.task (chain_id, task_order, kind, command)
    SELECT v_chain_id, 10, 'BUILTIN', 'SendMail'
    RETURNING task_id INTO v_mail_task_id;

    INSERT INTO timetable.parameter (task_id, order_id, value)
        VALUES (v_mail_task_id, 1,
                v_base_parameters ||
                jsonb_build_object (
                    'toaddr',   v_recipients,
                    'ccaddr',   v_cc_recipients,
                    'bccaddr',  v_bcc_recipients,
                    'subject',  v_subject,
                    'msgbody',  v_msgbody,
                    'attachment', ARRAY[]::text[]
                )
        );
    RETURN;
END;
$$ LANGUAGE 'plpgsql';
