#!/bin/sh

. ./.env

DB_HOST=`urlencode ${DATABASE_HOST:-cypex_database}`

mkdir -p ./certs

echo $DB_HOST

if [ -z "$(ls -A ./certs)" ]; then
  openssl req -new -x509 -days 365 -nodes -text -out ./certs/server.crt \
    -keyout ./certs/server.key -subj "/CN=$DB_HOST"
  chmod og-rwx ./certs/server.key

  openssl req -new -nodes -text -out ./certs/root.csr \
    -keyout ./certs/root.key -subj "/CN=localhost"
  chmod og-rwx ./certs/root.key

  openssl x509 -req -in ./certs/root.csr -text -days 3650 \
    -extfile /etc/ssl/openssl.cnf -extensions v3_ca \
    -signkey ./certs/root.key -out ./certs/root.crt

  openssl req -new -nodes -text -out ./certs/server.csr \
    -keyout ./certs/server.key -subj "/CN=$DB_HOST"
  chmod og-rwx ./certs/server.key

  openssl x509 -req -in ./certs/server.csr -text -days 365 \
    -CA ./certs/root.crt -CAkey ./certs/root.key -CAcreateserial \
    -out ./certs/server.crt
else
   echo "Skipping self-signed certificate generation. ./certs folder not empty."
fi

